.. _usage_yclept_config_help:

``yclept config-help``
========================

The command-line tool `yclept config-help <base.yaml>` allow you to use the interactive help feature detailed in :ref:`usage_interactive_help` to explore a base configuration file.  For example, if you have a base configuration file called `base.yaml`, you can run the following command:

.. code-block:: console

   $ yclept config-help base.yaml
